import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::AppFlow::Flow.
 */
export declare function getFlow(args: GetFlowArgs, opts?: pulumi.InvokeOptions): Promise<GetFlowResult>;
export interface GetFlowArgs {
    /**
     * Name of the flow.
     */
    flowName: string;
}
export interface GetFlowResult {
    /**
     * Description of the flow.
     */
    readonly description?: string;
    /**
     * List of Destination connectors of the flow.
     */
    readonly destinationFlowConfigList?: outputs.appflow.FlowDestinationFlowConfig[];
    /**
     * ARN identifier of the flow.
     */
    readonly flowArn?: string;
    /**
     * Flow activation status for Scheduled- and Event-triggered flows
     */
    readonly flowStatus?: enums.appflow.FlowStatus;
    /**
     * Configurations of metadata catalog of the flow.
     */
    readonly metadataCatalogConfig?: outputs.appflow.FlowMetadataCatalogConfig;
    /**
     * Configurations of Source connector of the flow.
     */
    readonly sourceFlowConfig?: outputs.appflow.FlowSourceFlowConfig;
    /**
     * List of Tags.
     */
    readonly tags?: outputs.Tag[];
    /**
     * List of tasks for the flow.
     */
    readonly tasks?: outputs.appflow.FlowTask[];
    /**
     * Trigger settings of the flow.
     */
    readonly triggerConfig?: outputs.appflow.FlowTriggerConfig;
}
/**
 * Resource schema for AWS::AppFlow::Flow.
 */
export declare function getFlowOutput(args: GetFlowOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFlowResult>;
export interface GetFlowOutputArgs {
    /**
     * Name of the flow.
     */
    flowName: pulumi.Input<string>;
}
