import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppStream::AppBlockBuilder.
 */
export declare class AppBlockBuilder extends pulumi.CustomResource {
    /**
     * Get an existing AppBlockBuilder resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AppBlockBuilder;
    /**
     * Returns true if the given object is an instance of AppBlockBuilder.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AppBlockBuilder;
    /**
     * The access endpoints of the app block builder.
     */
    readonly accessEndpoints: pulumi.Output<outputs.appstream.AppBlockBuilderAccessEndpoint[] | undefined>;
    /**
     * The ARN of the app block.
     *
     * *Maximum* : `1`
     */
    readonly appBlockArns: pulumi.Output<string[] | undefined>;
    /**
     * The ARN of the app block builder.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time when the app block builder was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the app block builder.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the app block builder.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * Indicates whether default internet access is enabled for the app block builder.
     */
    readonly enableDefaultInternetAccess: pulumi.Output<boolean | undefined>;
    /**
     * The ARN of the IAM role that is applied to the app block builder.
     */
    readonly iamRoleArn: pulumi.Output<string | undefined>;
    /**
     * The instance type of the app block builder.
     */
    readonly instanceType: pulumi.Output<string>;
    /**
     * The name of the app block builder.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The platform of the app block builder.
     *
     * *Allowed values* : `WINDOWS_SERVER_2019`
     */
    readonly platform: pulumi.Output<string>;
    /**
     * The tags of the app block builder.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The VPC configuration for the app block builder.
     */
    readonly vpcConfig: pulumi.Output<outputs.appstream.AppBlockBuilderVpcConfig>;
    /**
     * Create a AppBlockBuilder resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppBlockBuilderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AppBlockBuilder resource.
 */
export interface AppBlockBuilderArgs {
    /**
     * The access endpoints of the app block builder.
     */
    accessEndpoints?: pulumi.Input<pulumi.Input<inputs.appstream.AppBlockBuilderAccessEndpointArgs>[]>;
    /**
     * The ARN of the app block.
     *
     * *Maximum* : `1`
     */
    appBlockArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the app block builder.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the app block builder.
     */
    displayName?: pulumi.Input<string>;
    /**
     * Indicates whether default internet access is enabled for the app block builder.
     */
    enableDefaultInternetAccess?: pulumi.Input<boolean>;
    /**
     * The ARN of the IAM role that is applied to the app block builder.
     */
    iamRoleArn?: pulumi.Input<string>;
    /**
     * The instance type of the app block builder.
     */
    instanceType: pulumi.Input<string>;
    /**
     * The name of the app block builder.
     */
    name?: pulumi.Input<string>;
    /**
     * The platform of the app block builder.
     *
     * *Allowed values* : `WINDOWS_SERVER_2019`
     */
    platform: pulumi.Input<string>;
    /**
     * The tags of the app block builder.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The VPC configuration for the app block builder.
     */
    vpcConfig: pulumi.Input<inputs.appstream.AppBlockBuilderVpcConfigArgs>;
}
