import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Backup::BackupPlan
 */
export declare function getBackupPlan(args: GetBackupPlanArgs, opts?: pulumi.InvokeOptions): Promise<GetBackupPlanResult>;
export interface GetBackupPlanArgs {
    /**
     * Uniquely identifies a backup plan.
     */
    backupPlanId: string;
}
export interface GetBackupPlanResult {
    /**
     * Uniquely identifies the backup plan to be associated with the selection of resources.
     */
    readonly backupPlan?: outputs.backup.BackupPlanResourceType;
    /**
     * An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, `arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50` .
     */
    readonly backupPlanArn?: string;
    /**
     * Uniquely identifies a backup plan.
     */
    readonly backupPlanId?: string;
    /**
     * The tags to assign to the backup plan.
     */
    readonly backupPlanTags?: {
        [key: string]: string;
    };
    /**
     * Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version Ids cannot be edited.
     */
    readonly versionId?: string;
}
/**
 * Resource Type definition for AWS::Backup::BackupPlan
 */
export declare function getBackupPlanOutput(args: GetBackupPlanOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBackupPlanResult>;
export interface GetBackupPlanOutputArgs {
    /**
     * Uniquely identifies a backup plan.
     */
    backupPlanId: pulumi.Input<string>;
}
