import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A public key that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html), or with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).
 */
export declare function getPublicKey(args: GetPublicKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetPublicKeyResult>;
export interface GetPublicKeyArgs {
    /**
     * The identifier of the public key.
     */
    id: string;
}
export interface GetPublicKeyResult {
    /**
     * The date and time when the public key was uploaded.
     */
    readonly createdTime?: string;
    /**
     * The identifier of the public key.
     */
    readonly id?: string;
    /**
     * Configuration information about a public key that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html), or with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).
     */
    readonly publicKeyConfig?: outputs.cloudfront.PublicKeyConfig;
}
/**
 * A public key that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html), or with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).
 */
export declare function getPublicKeyOutput(args: GetPublicKeyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPublicKeyResult>;
export interface GetPublicKeyOutputArgs {
    /**
     * The identifier of the public key.
     */
    id: pulumi.Input<string>;
}
