import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::CloudWatch::CompositeAlarm type specifies an alarm which aggregates the states of other Alarms (Metric or Composite Alarms) as defined by the AlarmRule expression
 */
export declare function getCompositeAlarm(args: GetCompositeAlarmArgs, opts?: pulumi.InvokeOptions): Promise<GetCompositeAlarmResult>;
export interface GetCompositeAlarmArgs {
    /**
     * The name of the Composite Alarm
     */
    alarmName: string;
}
export interface GetCompositeAlarmResult {
    /**
     * Indicates whether actions should be executed during any changes to the alarm state. The default is TRUE.
     */
    readonly actionsEnabled?: boolean;
    /**
     * Actions will be suppressed if the suppressor alarm is in the ALARM state. ActionsSuppressor can be an AlarmName or an Amazon Resource Name (ARN) from an existing alarm.
     */
    readonly actionsSuppressor?: string;
    /**
     * Actions will be suppressed if WaitPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    readonly actionsSuppressorExtensionPeriod?: number;
    /**
     * Actions will be suppressed if ExtensionPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    readonly actionsSuppressorWaitPeriod?: number;
    /**
     * The list of actions to execute when this alarm transitions into an ALARM state from any other state. Specify each action as an Amazon Resource Name (ARN).
     */
    readonly alarmActions?: string[];
    /**
     * The description of the alarm
     */
    readonly alarmDescription?: string;
    /**
     * Expression which aggregates the state of other Alarms (Metric or Composite Alarms)
     */
    readonly alarmRule?: string;
    /**
     * Amazon Resource Name (ARN) of the alarm
     */
    readonly arn?: string;
    /**
     * The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    readonly insufficientDataActions?: string[];
    /**
     * The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    readonly okActions?: string[];
    /**
     * A list of key-value pairs to associate with the composite alarm. You can associate as many as 50 tags with an alarm.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::CloudWatch::CompositeAlarm type specifies an alarm which aggregates the states of other Alarms (Metric or Composite Alarms) as defined by the AlarmRule expression
 */
export declare function getCompositeAlarmOutput(args: GetCompositeAlarmOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCompositeAlarmResult>;
export interface GetCompositeAlarmOutputArgs {
    /**
     * The name of the Composite Alarm
     */
    alarmName: pulumi.Input<string>;
}
