import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * This resource schema represents the Profiling Group resource in the Amazon CodeGuru Profiler service.
 */
export declare function getProfilingGroup(args: GetProfilingGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetProfilingGroupResult>;
export interface GetProfilingGroupArgs {
    /**
     * The name of the profiling group.
     */
    profilingGroupName: string;
}
export interface GetProfilingGroupResult {
    /**
     * The agent permissions attached to this profiling group.
     */
    readonly agentPermissions?: outputs.codeguruprofiler.AgentPermissionsProperties;
    /**
     * Configuration for Notification Channels for Anomaly Detection feature in CodeGuru Profiler which enables customers to detect anomalies in the application profile for those methods that represent the highest proportion of CPU time or latency
     */
    readonly anomalyDetectionNotificationConfiguration?: outputs.codeguruprofiler.ProfilingGroupChannel[];
    /**
     * The Amazon Resource Name (ARN) of the specified profiling group.
     */
    readonly arn?: string;
    /**
     * The tags associated with a profiling group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * This resource schema represents the Profiling Group resource in the Amazon CodeGuru Profiler service.
 */
export declare function getProfilingGroupOutput(args: GetProfilingGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProfilingGroupResult>;
export interface GetProfilingGroupOutputArgs {
    /**
     * The name of the profiling group.
     */
    profilingGroupName: pulumi.Input<string>;
}
