import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::CodePipeline::CustomActionType resource creates a custom action for activities that aren't included in the CodePipeline default actions, such as running an internally developed build process or a test suite. You can use these custom actions in the stage of a pipeline.
 */
export declare function getCustomActionType(args: GetCustomActionTypeArgs, opts?: pulumi.InvokeOptions): Promise<GetCustomActionTypeResult>;
export interface GetCustomActionTypeArgs {
    /**
     * The category of the custom action, such as a build action or a test action.
     */
    category: string;
    /**
     * The provider of the service used in the custom action, such as AWS CodeDeploy.
     */
    provider: string;
    /**
     * The version identifier of the custom action.
     */
    version: string;
}
export interface GetCustomActionTypeResult {
    readonly id?: string;
    /**
     * Any tags assigned to the custom action.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::CodePipeline::CustomActionType resource creates a custom action for activities that aren't included in the CodePipeline default actions, such as running an internally developed build process or a test suite. You can use these custom actions in the stage of a pipeline.
 */
export declare function getCustomActionTypeOutput(args: GetCustomActionTypeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCustomActionTypeResult>;
export interface GetCustomActionTypeOutputArgs {
    /**
     * The category of the custom action, such as a build action or a test action.
     */
    category: pulumi.Input<string>;
    /**
     * The provider of the service used in the custom action, such as AWS CodeDeploy.
     */
    provider: pulumi.Input<string>;
    /**
     * The version identifier of the custom action.
     */
    version: pulumi.Input<string>;
}
