import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Schema for AWS::CodeStarConnections::Connection resource which can be used to connect external source providers with AWS CodePipeline
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleConnection = new aws_native.codestarconnections.Connection("sampleConnection", {
 *     connectionName: "MyConnection",
 *     providerType: "Bitbucket",
 *     tags: [{
 *         key: "Project",
 *         value: "ProjectB",
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleConnection = new aws_native.codestarconnections.Connection("sampleConnection", {
 *     connectionName: "MyConnection",
 *     providerType: "Bitbucket",
 *     tags: [{
 *         key: "Project",
 *         value: "ProjectB",
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleConnection = new aws_native.codestarconnections.Connection("sampleConnection", {
 *     connectionName: "MyConnection",
 *     providerType: "GitHubEnterpriseServer",
 *     hostArn: "arn:aws:codestar-connections:us-west-2:123456789123:host/abc123-example",
 *     tags: [{
 *         key: "Project",
 *         value: "ProjectB",
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const sampleConnection = new aws_native.codestarconnections.Connection("sampleConnection", {
 *     connectionName: "MyConnection",
 *     providerType: "GitHubEnterpriseServer",
 *     hostArn: "arn:aws:codestar-connections:us-west-2:123456789123:host/abc123-example",
 *     tags: [{
 *         key: "Project",
 *         value: "ProjectB",
 *     }],
 * });
 *
 * ```
 */
export declare class Connection extends pulumi.CustomResource {
    /**
     * Get an existing Connection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Connection;
    /**
     * Returns true if the given object is an instance of Connection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Connection;
    /**
     * The Amazon Resource Name (ARN) of the  connection. The ARN is used as the connection reference when the connection is shared between AWS services.
     */
    readonly connectionArn: pulumi.Output<string>;
    /**
     * The name of the connection. Connection names must be unique in an AWS user account.
     */
    readonly connectionName: pulumi.Output<string>;
    /**
     * The current status of the connection.
     */
    readonly connectionStatus: pulumi.Output<string>;
    /**
     * The host arn configured to represent the infrastructure where your third-party provider is installed. You must specify either a ProviderType or a HostArn.
     */
    readonly hostArn: pulumi.Output<string | undefined>;
    /**
     * The name of the external provider where your third-party code repository is configured. For Bitbucket, this is the account ID of the owner of the Bitbucket repository.
     */
    readonly ownerAccountId: pulumi.Output<string>;
    /**
     * The name of the external provider where your third-party code repository is configured. You must specify either a ProviderType or a HostArn.
     */
    readonly providerType: pulumi.Output<string | undefined>;
    /**
     * Specifies the tags applied to a connection.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Connection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Connection resource.
 */
export interface ConnectionArgs {
    /**
     * The name of the connection. Connection names must be unique in an AWS user account.
     */
    connectionName?: pulumi.Input<string>;
    /**
     * The host arn configured to represent the infrastructure where your third-party provider is installed. You must specify either a ProviderType or a HostArn.
     */
    hostArn?: pulumi.Input<string>;
    /**
     * The name of the external provider where your third-party code repository is configured. You must specify either a ProviderType or a HostArn.
     */
    providerType?: pulumi.Input<string>;
    /**
     * Specifies the tags applied to a connection.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
