import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::Comprehend::Flywheel resource creates an Amazon Comprehend Flywheel that enables customer to train their model.
 */
export declare function getFlywheel(args: GetFlywheelArgs, opts?: pulumi.InvokeOptions): Promise<GetFlywheelResult>;
export interface GetFlywheelArgs {
    /**
     * The Amazon Resource Name (ARN) of the flywheel.
     */
    arn: string;
}
export interface GetFlywheelResult {
    /**
     * The Amazon Resource Number (ARN) of the active model version.
     */
    readonly activeModelArn?: string;
    /**
     * The Amazon Resource Name (ARN) of the flywheel.
     */
    readonly arn?: string;
    /**
     * The Amazon Resource Name (ARN) of the IAM role that grants Amazon Comprehend permission to access the flywheel data.
     */
    readonly dataAccessRoleArn?: string;
    /**
     * Data security configuration.
     */
    readonly dataSecurityConfig?: outputs.comprehend.FlywheelDataSecurityConfig;
    /**
     * Tags associated with the endpoint being created. A tag is a key-value pair that adds metadata to the endpoint. For example, a tag with "Sales" as the key might be added to an endpoint to indicate its use by the sales department.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::Comprehend::Flywheel resource creates an Amazon Comprehend Flywheel that enables customer to train their model.
 */
export declare function getFlywheelOutput(args: GetFlywheelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFlywheelResult>;
export interface GetFlywheelOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the flywheel.
     */
    arn: pulumi.Input<string>;
}
