import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::InstanceStorageConfig
 */
export declare function getInstanceStorageConfig(args: GetInstanceStorageConfigArgs, opts?: pulumi.InvokeOptions): Promise<GetInstanceStorageConfigResult>;
export interface GetInstanceStorageConfigArgs {
    /**
     * The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
     */
    associationId: string;
    /**
     * Connect Instance ID with which the storage config will be associated
     */
    instanceArn: string;
    /**
     * A valid resource type. Following are the valid resource types: `CHAT_TRANSCRIPTS` | `CALL_RECORDINGS` | `SCHEDULED_REPORTS` | `MEDIA_STREAMS` | `CONTACT_TRACE_RECORDS` | `AGENT_EVENTS`
     */
    resourceType: enums.connect.InstanceStorageConfigInstanceStorageResourceType;
}
export interface GetInstanceStorageConfigResult {
    /**
     * The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
     */
    readonly associationId?: string;
    /**
     * The configuration of the Kinesis Firehose delivery stream.
     */
    readonly kinesisFirehoseConfig?: outputs.connect.InstanceStorageConfigKinesisFirehoseConfig;
    /**
     * The configuration of the Kinesis data stream.
     */
    readonly kinesisStreamConfig?: outputs.connect.InstanceStorageConfigKinesisStreamConfig;
    /**
     * The configuration of the Kinesis video stream.
     */
    readonly kinesisVideoStreamConfig?: outputs.connect.InstanceStorageConfigKinesisVideoStreamConfig;
    /**
     * The S3 bucket configuration.
     */
    readonly s3Config?: outputs.connect.InstanceStorageConfigS3Config;
    /**
     * A valid storage type.
     */
    readonly storageType?: enums.connect.InstanceStorageConfigStorageType;
}
/**
 * Resource Type definition for AWS::Connect::InstanceStorageConfig
 */
export declare function getInstanceStorageConfigOutput(args: GetInstanceStorageConfigOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInstanceStorageConfigResult>;
export interface GetInstanceStorageConfigOutputArgs {
    /**
     * The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
     */
    associationId: pulumi.Input<string>;
    /**
     * Connect Instance ID with which the storage config will be associated
     */
    instanceArn: pulumi.Input<string>;
    /**
     * A valid resource type. Following are the valid resource types: `CHAT_TRANSCRIPTS` | `CALL_RECORDINGS` | `SCHEDULED_REPORTS` | `MEDIA_STREAMS` | `CONTACT_TRACE_RECORDS` | `AGENT_EVENTS`
     */
    resourceType: pulumi.Input<enums.connect.InstanceStorageConfigInstanceStorageResourceType>;
}
