import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::Queue
 */
export declare function getQueue(args: GetQueueArgs, opts?: pulumi.InvokeOptions): Promise<GetQueueResult>;
export interface GetQueueArgs {
    /**
     * The Amazon Resource Name (ARN) for the queue.
     */
    queueArn: string;
}
export interface GetQueueResult {
    /**
     * The description of the queue.
     */
    readonly description?: string;
    /**
     * The identifier for the hours of operation.
     */
    readonly hoursOfOperationArn?: string;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn?: string;
    /**
     * The maximum number of contacts that can be in the queue before it is considered full.
     */
    readonly maxContacts?: number;
    /**
     * The name of the queue.
     */
    readonly name?: string;
    /**
     * The outbound caller ID name, number, and outbound whisper flow.
     */
    readonly outboundCallerConfig?: outputs.connect.QueueOutboundCallerConfig;
    /**
     * The outbound email address ID.
     */
    readonly outboundEmailConfig?: outputs.connect.QueueOutboundEmailConfig;
    /**
     * The Amazon Resource Name (ARN) for the queue.
     */
    readonly queueArn?: string;
    /**
     * The quick connects available to agents who are working the queue.
     */
    readonly quickConnectArns?: string[];
    /**
     * The status of the queue.
     */
    readonly status?: enums.connect.QueueStatus;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The type of queue.
     */
    readonly type?: enums.connect.QueueType;
}
/**
 * Resource Type definition for AWS::Connect::Queue
 */
export declare function getQueueOutput(args: GetQueueOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetQueueResult>;
export interface GetQueueOutputArgs {
    /**
     * The Amazon Resource Name (ARN) for the queue.
     */
    queueArn: pulumi.Input<string>;
}
