import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::HoursOfOperation
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const hoursOfOperation = new aws_native.connect.HoursOfOperation("hoursOfOperation", {
 *     name: "ExampleHoursOfOperation",
 *     description: "hours of operation created using cfn",
 *     instanceArn: "arn:aws:connect:region-name:aws-account-id:instance/instance-arn",
 *     timeZone: "Pacific/Midway",
 *     config: [{
 *         day: aws_native.connect.HoursOfOperationConfigDay.Sunday,
 *         endTime: {
 *             hours: 11,
 *             minutes: 59,
 *         },
 *         startTime: {
 *             hours: 10,
 *             minutes: 1,
 *         },
 *     }],
 *     tags: [{
 *         key: "tagKey",
 *         value: "tagValue",
 *     }],
 * });
 *
 * ```
 */
export declare class HoursOfOperation extends pulumi.CustomResource {
    /**
     * Get an existing HoursOfOperation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): HoursOfOperation;
    /**
     * Returns true if the given object is an instance of HoursOfOperation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HoursOfOperation;
    /**
     * Configuration information for the hours of operation: day, start time, and end time.
     */
    readonly config: pulumi.Output<outputs.connect.HoursOfOperationConfig[]>;
    /**
     * The description of the hours of operation.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the hours of operation.
     */
    readonly hoursOfOperationArn: pulumi.Output<string>;
    /**
     * One or more hours of operation overrides assigned to an hour of operation.
     */
    readonly hoursOfOperationOverrides: pulumi.Output<outputs.connect.HoursOfOperationOverride[] | undefined>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the hours of operation.
     */
    readonly name: pulumi.Output<string>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The time zone of the hours of operation.
     */
    readonly timeZone: pulumi.Output<string>;
    /**
     * Create a HoursOfOperation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HoursOfOperationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a HoursOfOperation resource.
 */
export interface HoursOfOperationArgs {
    /**
     * Configuration information for the hours of operation: day, start time, and end time.
     */
    config: pulumi.Input<pulumi.Input<inputs.connect.HoursOfOperationConfigArgs>[]>;
    /**
     * The description of the hours of operation.
     */
    description?: pulumi.Input<string>;
    /**
     * One or more hours of operation overrides assigned to an hour of operation.
     */
    hoursOfOperationOverrides?: pulumi.Input<pulumi.Input<inputs.connect.HoursOfOperationOverrideArgs>[]>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the hours of operation.
     */
    name?: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The time zone of the hours of operation.
     */
    timeZone: pulumi.Input<string>;
}
