import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::Prompt
 */
export declare class Prompt extends pulumi.CustomResource {
    /**
     * Get an existing Prompt resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Prompt;
    /**
     * Returns true if the given object is an instance of Prompt.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Prompt;
    /**
     * The description of the prompt.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the prompt.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) for the prompt.
     */
    readonly promptArn: pulumi.Output<string>;
    /**
     * S3 URI of the customer's audio file for creating prompts resource..
     */
    readonly s3Uri: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Prompt resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PromptArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Prompt resource.
 */
export interface PromptArgs {
    /**
     * The description of the prompt.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the prompt.
     */
    name?: pulumi.Input<string>;
    /**
     * S3 URI of the customer's audio file for creating prompts resource..
     */
    s3Uri?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
