import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::Task.
 */
export declare function getTask(args: GetTaskArgs, opts?: pulumi.InvokeOptions): Promise<GetTaskResult>;
export interface GetTaskArgs {
    /**
     * The ARN of the task.
     */
    taskArn: string;
}
export interface GetTaskResult {
    /**
     * The ARN of the Amazon CloudWatch log group that is used to monitor and log events in the task.
     */
    readonly cloudWatchLogGroupArn?: string;
    /**
     * The ARNs of the destination elastic network interfaces (ENIs) that were created for your subnet.
     */
    readonly destinationNetworkInterfaceArns?: string[];
    /**
     * Specifies exclude filters that define the files, objects, and folders in your source location that you don't want DataSync to transfer. For more information and examples, see [Specifying what DataSync transfers by using filters](https://docs.aws.amazon.com/datasync/latest/userguide/filtering.html) .
     */
    readonly excludes?: outputs.datasync.TaskFilterRule[];
    /**
     * Specifies include filters that define the files, objects, and folders in your source location that you want DataSync to transfer. For more information and examples, see [Specifying what DataSync transfers by using filters](https://docs.aws.amazon.com/datasync/latest/userguide/filtering.html) .
     */
    readonly includes?: outputs.datasync.TaskFilterRule[];
    /**
     * The configuration of the manifest that lists the files or objects that you want DataSync to transfer. For more information, see [Specifying what DataSync transfers by using a manifest](https://docs.aws.amazon.com/datasync/latest/userguide/transferring-with-manifest.html) .
     */
    readonly manifestConfig?: outputs.datasync.TaskManifestConfig;
    /**
     * The name of a task. This value is a text reference that is used to identify the task in the console.
     */
    readonly name?: string;
    /**
     * Specifies your task's settings, such as preserving file metadata, verifying data integrity, among other options.
     */
    readonly options?: outputs.datasync.TaskOptions;
    /**
     * Specifies a schedule for when you want your task to run. For more information, see [Scheduling your task](https://docs.aws.amazon.com/datasync/latest/userguide/task-scheduling.html) .
     */
    readonly schedule?: outputs.datasync.TaskSchedule;
    /**
     * The ARNs of the source ENIs that were created for your subnet.
     */
    readonly sourceNetworkInterfaceArns?: string[];
    /**
     * The status of the task that was described.
     */
    readonly status?: enums.datasync.TaskStatus;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ARN of the task.
     */
    readonly taskArn?: string;
    /**
     * Specifies how you want to configure a task report, which provides detailed information about your DataSync transfer. For more information, see [Monitoring your DataSync transfers with task reports](https://docs.aws.amazon.com/datasync/latest/userguide/task-reports.html) .
     *
     * When using this parameter, your caller identity (the role that you're using DataSync with) must have the `iam:PassRole` permission. The [AWSDataSyncFullAccess](https://docs.aws.amazon.com/datasync/latest/userguide/security-iam-awsmanpol.html#security-iam-awsmanpol-awsdatasyncfullaccess) policy includes this permission.
     */
    readonly taskReportConfig?: outputs.datasync.TaskReportConfig;
}
/**
 * Resource schema for AWS::DataSync::Task.
 */
export declare function getTaskOutput(args: GetTaskOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTaskResult>;
export interface GetTaskOutputArgs {
    /**
     * The ARN of the task.
     */
    taskArn: pulumi.Input<string>;
}
