import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::LocationObjectStorage.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const locationObjectStorage = new aws_native.datasync.LocationObjectStorage("locationObjectStorage", {
 *     agentArns: ["arn:aws:datasync:us-east-2:111222333444:agent/agent-0b0addbeef44b3nfs"],
 *     bucketName: "MyBucket",
 *     serverHostname: "MyServer@example.com",
 *     serverProtocol: aws_native.datasync.LocationObjectStorageServerProtocol.Https,
 *     subdirectory: "/MySubdirectory",
 * });
 *
 * ```
 */
export declare class LocationObjectStorage extends pulumi.CustomResource {
    /**
     * Get an existing LocationObjectStorage resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationObjectStorage;
    /**
     * Returns true if the given object is an instance of LocationObjectStorage.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationObjectStorage;
    /**
     * Optional. The access key is used if credentials are required to access the self-managed object storage server.
     */
    readonly accessKey: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the agents associated with the self-managed object storage server location.
     */
    readonly agentArns: pulumi.Output<string[]>;
    /**
     * The name of the bucket on the self-managed object storage server.
     */
    readonly bucketName: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the object storage location that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * Optional. The secret key is used if credentials are required to access the self-managed object storage server.
     */
    readonly secretKey: pulumi.Output<string | undefined>;
    /**
     * X.509 PEM content containing a certificate authority or chain to trust.
     */
    readonly serverCertificate: pulumi.Output<string | undefined>;
    /**
     * The name of the self-managed object storage server. This value is the IP address or Domain Name Service (DNS) name of the object storage server.
     */
    readonly serverHostname: pulumi.Output<string | undefined>;
    /**
     * The port that your self-managed server accepts inbound network traffic on.
     */
    readonly serverPort: pulumi.Output<number | undefined>;
    /**
     * The protocol that the object storage server uses to communicate.
     */
    readonly serverProtocol: pulumi.Output<enums.datasync.LocationObjectStorageServerProtocol | undefined>;
    /**
     * The subdirectory in the self-managed object storage server that is used to read data from.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationObjectStorage resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationObjectStorageArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationObjectStorage resource.
 */
export interface LocationObjectStorageArgs {
    /**
     * Optional. The access key is used if credentials are required to access the self-managed object storage server.
     */
    accessKey?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the agents associated with the self-managed object storage server location.
     */
    agentArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the bucket on the self-managed object storage server.
     */
    bucketName?: pulumi.Input<string>;
    /**
     * Optional. The secret key is used if credentials are required to access the self-managed object storage server.
     */
    secretKey?: pulumi.Input<string>;
    /**
     * X.509 PEM content containing a certificate authority or chain to trust.
     */
    serverCertificate?: pulumi.Input<string>;
    /**
     * The name of the self-managed object storage server. This value is the IP address or Domain Name Service (DNS) name of the object storage server.
     */
    serverHostname?: pulumi.Input<string>;
    /**
     * The port that your self-managed server accepts inbound network traffic on.
     */
    serverPort?: pulumi.Input<number>;
    /**
     * The protocol that the object storage server uses to communicate.
     */
    serverProtocol?: pulumi.Input<enums.datasync.LocationObjectStorageServerProtocol>;
    /**
     * The subdirectory in the self-managed object storage server that is used to read data from.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
