import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A domain is an organizing entity for connecting together assets, users, and their projects
 */
export declare function getDomain(args: GetDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainResult>;
export interface GetDomainArgs {
    /**
     * The id of the Amazon DataZone domain.
     */
    id: string;
}
export interface GetDomainResult {
    /**
     * The ARN of the Amazon DataZone domain.
     */
    readonly arn?: string;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     */
    readonly createdAt?: string;
    /**
     * The description of the Amazon DataZone domain.
     */
    readonly description?: string;
    /**
     * The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the AWS account that houses the Amazon DataZone domain.
     */
    readonly domainExecutionRole?: string;
    /**
     * The id of the Amazon DataZone domain.
     */
    readonly id?: string;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The identifier of the AWS account that manages the domain.
     */
    readonly managedAccountId?: string;
    /**
     * The name of the Amazon DataZone domain.
     */
    readonly name?: string;
    /**
     * The URL of the data portal for this Amazon DataZone domain.
     */
    readonly portalUrl?: string;
    /**
     * The ID of the root domain in Amazon Datazone.
     */
    readonly rootDomainUnitId?: string;
    /**
     * The service role of the domain that is created.
     */
    readonly serviceRole?: string;
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     */
    readonly singleSignOn?: outputs.datazone.DomainSingleSignOn;
    /**
     * The status of the Amazon DataZone domain.
     */
    readonly status?: enums.datazone.DomainStatus;
    /**
     * The tags specified for the Amazon DataZone domain.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A domain is an organizing entity for connecting together assets, users, and their projects
 */
export declare function getDomainOutput(args: GetDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainResult>;
export interface GetDomainOutputArgs {
    /**
     * The id of the Amazon DataZone domain.
     */
    id: pulumi.Input<string>;
}
