import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DMS::MigrationProject
 */
export declare function getMigrationProject(args: GetMigrationProjectArgs, opts?: pulumi.InvokeOptions): Promise<GetMigrationProjectResult>;
export interface GetMigrationProjectArgs {
    /**
     * The property describes an ARN of the migration project.
     */
    migrationProjectArn: string;
}
export interface GetMigrationProjectResult {
    /**
     * The optional description of the migration project.
     */
    readonly description?: string;
    /**
     * The property describes an instance profile arn for the migration project. For read
     */
    readonly instanceProfileArn?: string;
    /**
     * The property describes an instance profile name for the migration project. For read
     */
    readonly instanceProfileName?: string;
    /**
     * The property describes an ARN of the migration project.
     */
    readonly migrationProjectArn?: string;
    /**
     * The property describes a creating time of the migration project.
     */
    readonly migrationProjectCreationTime?: string;
    /**
     * The property describes a name to identify the migration project.
     */
    readonly migrationProjectName?: string;
    /**
     * The property describes schema conversion application attributes for the migration project.
     */
    readonly schemaConversionApplicationAttributes?: outputs.dms.SchemaConversionApplicationAttributesProperties;
    /**
     * The property describes source data provider descriptors for the migration project.
     */
    readonly sourceDataProviderDescriptors?: outputs.dms.MigrationProjectDataProviderDescriptor[];
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The property describes target data provider descriptors for the migration project.
     */
    readonly targetDataProviderDescriptors?: outputs.dms.MigrationProjectDataProviderDescriptor[];
    /**
     * The property describes transformation rules for the migration project.
     */
    readonly transformationRules?: string;
}
/**
 * Resource schema for AWS::DMS::MigrationProject
 */
export declare function getMigrationProjectOutput(args: GetMigrationProjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMigrationProjectResult>;
export interface GetMigrationProjectOutputArgs {
    /**
     * The property describes an ARN of the migration project.
     */
    migrationProjectArn: pulumi.Input<string>;
}
