import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A replication configuration that you later provide to configure and start a AWS DMS Serverless replication
 */
export declare function getReplicationConfig(args: GetReplicationConfigArgs, opts?: pulumi.InvokeOptions): Promise<GetReplicationConfigResult>;
export interface GetReplicationConfigArgs {
    /**
     * The Amazon Resource Name (ARN) of the Replication Config
     */
    replicationConfigArn: string;
}
export interface GetReplicationConfigResult {
    /**
     * Configuration parameters for provisioning an AWS DMS Serverless replication.
     */
    readonly computeConfig?: outputs.dms.ReplicationConfigComputeConfig;
    /**
     * The Amazon Resource Name (ARN) of the Replication Config
     */
    readonly replicationConfigArn?: string;
    /**
     * A unique identifier of replication configuration
     */
    readonly replicationConfigIdentifier?: string;
    /**
     * JSON settings for Servereless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly replicationSettings?: any;
    /**
     * The type of AWS DMS Serverless replication to provision using this replication configuration
     */
    readonly replicationType?: enums.dms.ReplicationConfigReplicationType;
    /**
     * The Amazon Resource Name (ARN) of the source endpoint for this AWS DMS Serverless replication configuration
     */
    readonly sourceEndpointArn?: string;
    /**
     * JSON settings for specifying supplemental data
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly supplementalSettings?: any;
    /**
     * JSON table mappings for AWS DMS Serverless replications that are provisioned using this replication configuration
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::DMS::ReplicationConfig` for more information about the expected schema for this property.
     */
    readonly tableMappings?: any;
    /**
     * <p>Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.</p>
     */
    readonly tags?: outputs.Tag[];
    /**
     * The Amazon Resource Name (ARN) of the target endpoint for this AWS DMS Serverless replication configuration
     */
    readonly targetEndpointArn?: string;
}
/**
 * A replication configuration that you later provide to configure and start a AWS DMS Serverless replication
 */
export declare function getReplicationConfigOutput(args: GetReplicationConfigOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetReplicationConfigResult>;
export interface GetReplicationConfigOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the Replication Config
     */
    replicationConfigArn: pulumi.Input<string>;
}
