import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::NetworkInterface resource creates network interface
 */
export declare function getNetworkInterface(args: GetNetworkInterfaceArgs, opts?: pulumi.InvokeOptions): Promise<GetNetworkInterfaceResult>;
export interface GetNetworkInterfaceArgs {
    /**
     * Network interface id.
     */
    id: string;
}
export interface GetNetworkInterfaceResult {
    /**
     * A connection tracking specification for the network interface.
     */
    readonly connectionTrackingSpecification?: outputs.ec2.NetworkInterfaceConnectionTrackingSpecification;
    /**
     * A description for the network interface.
     */
    readonly description?: string;
    /**
     * If you have instances or ENIs that rely on the IPv6 address not changing, to avoid disrupting traffic to instances or ENIs, you can enable a primary IPv6 address. Enable this option to automatically assign an IPv6 associated with the ENI attached to your instance to be the primary IPv6 address. When you enable an IPv6 address to be a primary IPv6, you cannot disable it. Traffic will be routed to the primary IPv6 address until the instance is terminated or the ENI is detached. If you have multiple IPv6 addresses associated with an ENI and you enable a primary IPv6 address, the first IPv6 address associated with the ENI becomes the primary IPv6 address.
     */
    readonly enablePrimaryIpv6?: boolean;
    /**
     * A list of security group IDs associated with this network interface.
     */
    readonly groupSet?: string[];
    /**
     * Network interface id.
     */
    readonly id?: string;
    /**
     * The number of IPv4 prefixes to assign to a network interface. When you specify a number of IPv4 prefixes, Amazon EC2 selects these prefixes from your existing subnet CIDR reservations, if available, or from free spaces in the subnet. By default, these will be /28 prefixes. You can't specify a count of IPv4 prefixes if you've specified one of the following: specific IPv4 prefixes, specific private IPv4 addresses, or a count of private IPv4 addresses.
     */
    readonly ipv4PrefixCount?: number;
    /**
     * Assigns a list of IPv4 prefixes to the network interface. If you want EC2 to automatically assign IPv4 prefixes, use the Ipv4PrefixCount property and do not specify this property. Presently, only /28 prefixes are supported. You can't specify IPv4 prefixes if you've specified one of the following: a count of IPv4 prefixes, specific private IPv4 addresses, or a count of private IPv4 addresses.
     */
    readonly ipv4Prefixes?: outputs.ec2.NetworkInterfaceIpv4PrefixSpecification[];
    /**
     * The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. To specify specific IPv6 addresses, use the Ipv6Addresses property and don't specify this property.
     */
    readonly ipv6AddressCount?: number;
    /**
     * One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet to associate with the network interface. If you're specifying a number of IPv6 addresses, use the Ipv6AddressCount property and don't specify this property.
     */
    readonly ipv6Addresses?: outputs.ec2.NetworkInterfaceInstanceIpv6Address[];
    /**
     * The number of IPv6 prefixes to assign to a network interface. When you specify a number of IPv6 prefixes, Amazon EC2 selects these prefixes from your existing subnet CIDR reservations, if available, or from free spaces in the subnet. By default, these will be /80 prefixes. You can't specify a count of IPv6 prefixes if you've specified one of the following: specific IPv6 prefixes, specific IPv6 addresses, or a count of IPv6 addresses.
     */
    readonly ipv6PrefixCount?: number;
    /**
     * Assigns a list of IPv6 prefixes to the network interface. If you want EC2 to automatically assign IPv6 prefixes, use the Ipv6PrefixCount property and do not specify this property. Presently, only /80 prefixes are supported. You can't specify IPv6 prefixes if you've specified one of the following: a count of IPv6 prefixes, specific IPv6 addresses, or a count of IPv6 addresses.
     */
    readonly ipv6Prefixes?: outputs.ec2.NetworkInterfaceIpv6PrefixSpecification[];
    /**
     * The primary IPv6 address
     */
    readonly primaryIpv6Address?: string;
    /**
     * Returns the primary private IP address of the network interface.
     */
    readonly primaryPrivateIpAddress?: string;
    /**
     * Assigns a list of private IP addresses to the network interface. You can specify a primary private IP address by setting the value of the Primary property to true in the PrivateIpAddressSpecification property. If you want EC2 to automatically assign private IP addresses, use the SecondaryPrivateIpAddressCount property and do not specify this property.
     */
    readonly privateIpAddresses?: outputs.ec2.NetworkInterfacePrivateIpAddressSpecification[];
    /**
     * The number of secondary private IPv4 addresses to assign to a network interface. When you specify a number of secondary IPv4 addresses, Amazon EC2 selects these IP addresses within the subnet's IPv4 CIDR range. You can't specify this option and specify more than one private IP address using privateIpAddresses
     */
    readonly secondaryPrivateIpAddressCount?: number;
    /**
     * Returns the secondary private IP addresses of the network interface.
     */
    readonly secondaryPrivateIpAddresses?: string[];
    /**
     * Indicates whether traffic to or from the instance is validated.
     */
    readonly sourceDestCheck?: boolean;
    /**
     * An arbitrary set of tags (key-value pairs) for this network interface.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ID of the VPC
     */
    readonly vpcId?: string;
}
/**
 * The AWS::EC2::NetworkInterface resource creates network interface
 */
export declare function getNetworkInterfaceOutput(args: GetNetworkInterfaceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetNetworkInterfaceResult>;
export interface GetNetworkInterfaceOutputArgs {
    /**
     * Network interface id.
     */
    id: pulumi.Input<string>;
}
