import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EC2::SecurityGroup
 */
export declare function getSecurityGroup(args: GetSecurityGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityGroupResult>;
export interface GetSecurityGroupArgs {
    /**
     * The group name or group ID depending on whether the SG is created in default or specific VPC
     */
    id: string;
}
export interface GetSecurityGroupResult {
    /**
     * The group ID of the specified security group.
     */
    readonly groupId?: string;
    /**
     * The group name or group ID depending on whether the SG is created in default or specific VPC
     */
    readonly id?: string;
    /**
     * [VPC only] The outbound rules associated with the security group. There is a short interruption during which you cannot connect to the security group.
     */
    readonly securityGroupEgress?: outputs.ec2.SecurityGroupEgress[];
    /**
     * The inbound rules associated with the security group. There is a short interruption during which you cannot connect to the security group.
     */
    readonly securityGroupIngress?: outputs.ec2.SecurityGroupIngress[];
    /**
     * Any tags assigned to the security group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::EC2::SecurityGroup
 */
export declare function getSecurityGroupOutput(args: GetSecurityGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSecurityGroupResult>;
export interface GetSecurityGroupOutputArgs {
    /**
     * The group name or group ID depending on whether the SG is created in default or specific VPC
     */
    id: pulumi.Input<string>;
}
