import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::EC2::VPCCidrBlock
 */
export declare class VpcCidrBlock extends pulumi.CustomResource {
    /**
     * Get an existing VpcCidrBlock resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcCidrBlock;
    /**
     * Returns true if the given object is an instance of VpcCidrBlock.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcCidrBlock;
    /**
     * Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IPv6 addresses, or the size of the CIDR block.
     */
    readonly amazonProvidedIpv6CidrBlock: pulumi.Output<boolean | undefined>;
    /**
     * The Id of the VPC associated CIDR Block.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * An IPv4 CIDR block to associate with the VPC.
     */
    readonly cidrBlock: pulumi.Output<string | undefined>;
    /**
     * The IP Source of an IPv6 VPC CIDR Block.
     */
    readonly ipSource: pulumi.Output<string>;
    /**
     * The ID of the IPv4 IPAM pool to Associate a CIDR from to a VPC.
     */
    readonly ipv4IpamPoolId: pulumi.Output<string | undefined>;
    /**
     * The netmask length of the IPv4 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool.
     */
    readonly ipv4NetmaskLength: pulumi.Output<number | undefined>;
    /**
     * The value denoting whether an IPv6 VPC CIDR Block is public or private.
     */
    readonly ipv6AddressAttribute: pulumi.Output<string>;
    /**
     * An IPv6 CIDR block from the IPv6 address pool.
     */
    readonly ipv6CidrBlock: pulumi.Output<string | undefined>;
    /**
     * The name of the location from which we advertise the IPV6 CIDR block.
     */
    readonly ipv6CidrBlockNetworkBorderGroup: pulumi.Output<string | undefined>;
    /**
     * The ID of the IPv6 IPAM pool to Associate a CIDR from to a VPC.
     */
    readonly ipv6IpamPoolId: pulumi.Output<string | undefined>;
    /**
     * The netmask length of the IPv6 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool.
     */
    readonly ipv6NetmaskLength: pulumi.Output<number | undefined>;
    /**
     * The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
     */
    readonly ipv6Pool: pulumi.Output<string | undefined>;
    /**
     * The ID of the VPC.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a VpcCidrBlock resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcCidrBlockArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcCidrBlock resource.
 */
export interface VpcCidrBlockArgs {
    /**
     * Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IPv6 addresses, or the size of the CIDR block.
     */
    amazonProvidedIpv6CidrBlock?: pulumi.Input<boolean>;
    /**
     * An IPv4 CIDR block to associate with the VPC.
     */
    cidrBlock?: pulumi.Input<string>;
    /**
     * The ID of the IPv4 IPAM pool to Associate a CIDR from to a VPC.
     */
    ipv4IpamPoolId?: pulumi.Input<string>;
    /**
     * The netmask length of the IPv4 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool.
     */
    ipv4NetmaskLength?: pulumi.Input<number>;
    /**
     * An IPv6 CIDR block from the IPv6 address pool.
     */
    ipv6CidrBlock?: pulumi.Input<string>;
    /**
     * The name of the location from which we advertise the IPV6 CIDR block.
     */
    ipv6CidrBlockNetworkBorderGroup?: pulumi.Input<string>;
    /**
     * The ID of the IPv6 IPAM pool to Associate a CIDR from to a VPC.
     */
    ipv6IpamPoolId?: pulumi.Input<string>;
    /**
     * The netmask length of the IPv6 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool.
     */
    ipv6NetmaskLength?: pulumi.Input<number>;
    /**
     * The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
     */
    ipv6Pool?: pulumi.Input<string>;
    /**
     * The ID of the VPC.
     */
    vpcId: pulumi.Input<string>;
}
