import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::EC2::VPCEndpointService
 */
export declare class VpcEndpointService extends pulumi.CustomResource {
    /**
     * Get an existing VpcEndpointService resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcEndpointService;
    /**
     * Returns true if the given object is an instance of VpcEndpointService.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcEndpointService;
    /**
     * Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
     */
    readonly acceptanceRequired: pulumi.Output<boolean | undefined>;
    /**
     * Indicates whether to enable the built-in Contributor Insights rules provided by AWS PrivateLink .
     */
    readonly contributorInsightsEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
     */
    readonly gatewayLoadBalancerArns: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Names (ARNs) of the Network Load Balancers.
     */
    readonly networkLoadBalancerArns: pulumi.Output<string[] | undefined>;
    /**
     * The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
     */
    readonly payerResponsibility: pulumi.Output<string | undefined>;
    /**
     * The ID of the endpoint service.
     */
    readonly serviceId: pulumi.Output<string>;
    /**
     * Specify which Ip Address types are supported for VPC endpoint service.
     */
    readonly supportedIpAddressTypes: pulumi.Output<enums.ec2.VpcEndpointServiceIpAddressType[] | undefined>;
    /**
     * The Regions from which service consumers can access the service.
     */
    readonly supportedRegions: pulumi.Output<string[] | undefined>;
    /**
     * The tags to add to the VPC endpoint service.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a VpcEndpointService resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: VpcEndpointServiceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcEndpointService resource.
 */
export interface VpcEndpointServiceArgs {
    /**
     * Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
     */
    acceptanceRequired?: pulumi.Input<boolean>;
    /**
     * Indicates whether to enable the built-in Contributor Insights rules provided by AWS PrivateLink .
     */
    contributorInsightsEnabled?: pulumi.Input<boolean>;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
     */
    gatewayLoadBalancerArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Amazon Resource Names (ARNs) of the Network Load Balancers.
     */
    networkLoadBalancerArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
     */
    payerResponsibility?: pulumi.Input<string>;
    /**
     * Specify which Ip Address types are supported for VPC endpoint service.
     */
    supportedIpAddressTypes?: pulumi.Input<pulumi.Input<enums.ec2.VpcEndpointServiceIpAddressType>[]>;
    /**
     * The Regions from which service consumers can access the service.
     */
    supportedRegions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags to add to the VPC endpoint service.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
