import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The scanning configuration for a private registry.
 */
export declare class RegistryScanningConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing RegistryScanningConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RegistryScanningConfiguration;
    /**
     * Returns true if the given object is an instance of RegistryScanningConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RegistryScanningConfiguration;
    /**
     * The account ID of the destination registry.
     */
    readonly registryId: pulumi.Output<string>;
    /**
     * The scanning rules associated with the registry.
     */
    readonly rules: pulumi.Output<outputs.ecr.RegistryScanningConfigurationScanningRule[]>;
    /**
     * The type of scanning configured for the registry.
     */
    readonly scanType: pulumi.Output<enums.ecr.RegistryScanningConfigurationScanType>;
    /**
     * Create a RegistryScanningConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RegistryScanningConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RegistryScanningConfiguration resource.
 */
export interface RegistryScanningConfigurationArgs {
    /**
     * The scanning rules associated with the registry.
     */
    rules: pulumi.Input<pulumi.Input<inputs.ecr.RegistryScanningConfigurationScanningRuleArgs>[]>;
    /**
     * The type of scanning configured for the registry.
     */
    scanType: pulumi.Input<enums.ecr.RegistryScanningConfigurationScanType>;
}
