import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::ElastiCache::UserGroup
 */
export declare function getUserGroup(args: GetUserGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetUserGroupResult>;
export interface GetUserGroupArgs {
    /**
     * The ID of the user group.
     */
    userGroupId: string;
}
export interface GetUserGroupResult {
    /**
     * The Amazon Resource Name (ARN) of the user account.
     */
    readonly arn?: string;
    /**
     * The target cache engine for the user group.
     */
    readonly engine?: enums.elasticache.UserGroupEngine;
    /**
     * Indicates user group status. Can be "creating", "active", "modifying", "deleting".
     */
    readonly status?: string;
    /**
     * An array of key-value pairs to apply to this user.
     */
    readonly tags?: outputs.Tag[];
    /**
     * List of users associated to this user group.
     */
    readonly userIds?: string[];
}
/**
 * Resource Type definition for AWS::ElastiCache::UserGroup
 */
export declare function getUserGroupOutput(args: GetUserGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserGroupResult>;
export interface GetUserGroupOutputArgs {
    /**
     * The ID of the user group.
     */
    userGroupId: pulumi.Input<string>;
}
