import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A resource schema for a Variable in Amazon Fraud Detector.
 */
export declare class Variable extends pulumi.CustomResource {
    /**
     * Get an existing Variable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Variable;
    /**
     * Returns true if the given object is an instance of Variable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Variable;
    /**
     * The ARN of the variable.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time when the variable was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The source of the data.
     */
    readonly dataSource: pulumi.Output<enums.frauddetector.VariableDataSource>;
    /**
     * The data type.
     */
    readonly dataType: pulumi.Output<enums.frauddetector.VariableDataType>;
    /**
     * The default value for the variable when no value is received.
     */
    readonly defaultValue: pulumi.Output<string>;
    /**
     * The description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The time when the variable was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The name of the variable.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags associated with this variable.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The variable type. For more information see https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types
     */
    readonly variableType: pulumi.Output<enums.frauddetector.VariableType | undefined>;
    /**
     * Create a Variable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VariableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Variable resource.
 */
export interface VariableArgs {
    /**
     * The source of the data.
     */
    dataSource: pulumi.Input<enums.frauddetector.VariableDataSource>;
    /**
     * The data type.
     */
    dataType: pulumi.Input<enums.frauddetector.VariableDataType>;
    /**
     * The default value for the variable when no value is received.
     */
    defaultValue: pulumi.Input<string>;
    /**
     * The description.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the variable.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags associated with this variable.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The variable type. For more information see https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types
     */
    variableType?: pulumi.Input<enums.frauddetector.VariableType>;
}
