import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::GlobalAccelerator::Accelerator
 */
export declare class Accelerator extends pulumi.CustomResource {
    /**
     * Get an existing Accelerator resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Accelerator;
    /**
     * Returns true if the given object is an instance of Accelerator.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Accelerator;
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    readonly acceleratorArn: pulumi.Output<string>;
    /**
     * The Domain Name System (DNS) name that Global Accelerator creates that points to your accelerator's static IPv4 addresses.
     */
    readonly dnsName: pulumi.Output<string>;
    /**
     * The Domain Name System (DNS) name that Global Accelerator creates that points to your accelerator's static IPv4 and IPv6 addresses.
     */
    readonly dualStackDnsName: pulumi.Output<string>;
    /**
     * Indicates whether an accelerator is enabled. The value is true or false.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * IP Address type.
     */
    readonly ipAddressType: pulumi.Output<enums.globalaccelerator.AcceleratorIpAddressType | undefined>;
    /**
     * The IP addresses from BYOIP Prefix pool.
     */
    readonly ipAddresses: pulumi.Output<string[] | undefined>;
    /**
     * The IPv4 addresses assigned to the accelerator.
     */
    readonly ipv4Addresses: pulumi.Output<string[]>;
    /**
     * The IPv6 addresses assigned if the accelerator is dualstack
     */
    readonly ipv6Addresses: pulumi.Output<string[]>;
    /**
     * Name of accelerator.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create tags for an accelerator.
     *
     * For more information, see [Tagging](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Accelerator resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AcceleratorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Accelerator resource.
 */
export interface AcceleratorArgs {
    /**
     * Indicates whether an accelerator is enabled. The value is true or false.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * IP Address type.
     */
    ipAddressType?: pulumi.Input<enums.globalaccelerator.AcceleratorIpAddressType>;
    /**
     * The IP addresses from BYOIP Prefix pool.
     */
    ipAddresses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of accelerator.
     */
    name?: pulumi.Input<string>;
    /**
     * Create tags for an accelerator.
     *
     * For more information, see [Tagging](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
