import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::GlobalAccelerator::EndpointGroup
 */
export declare function getEndpointGroup(args: GetEndpointGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetEndpointGroupResult>;
export interface GetEndpointGroupArgs {
    /**
     * The Amazon Resource Name (ARN) of the endpoint group
     */
    endpointGroupArn: string;
}
export interface GetEndpointGroupResult {
    /**
     * The list of endpoint objects.
     */
    readonly endpointConfigurations?: outputs.globalaccelerator.EndpointGroupEndpointConfiguration[];
    /**
     * The Amazon Resource Name (ARN) of the endpoint group
     */
    readonly endpointGroupArn?: string;
    /**
     * The time in seconds between each health check for an endpoint. Must be a value of 10 or 30
     */
    readonly healthCheckIntervalSeconds?: number;
    /**
     * If the protocol is HTTP/S, then this value provides the ping path that Global Accelerator uses for the destination on the endpoints for health checks. The default is slash (/).
     */
    readonly healthCheckPath?: string;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    readonly healthCheckPort?: number;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    readonly healthCheckProtocol?: enums.globalaccelerator.EndpointGroupHealthCheckProtocol;
    /**
     * Allows you to override the destination ports used to route traffic to an endpoint. Using a port override lets you map a list of external destination ports (that your users send traffic to) to a list of internal destination ports that you want an application endpoint to receive traffic on.
     */
    readonly portOverrides?: outputs.globalaccelerator.EndpointGroupPortOverride[];
    /**
     * The number of consecutive health checks required to set the state of the endpoint to unhealthy.
     */
    readonly thresholdCount?: number;
    /**
     * The percentage of traffic to sent to an AWS Region
     */
    readonly trafficDialPercentage?: number;
}
/**
 * Resource Type definition for AWS::GlobalAccelerator::EndpointGroup
 */
export declare function getEndpointGroupOutput(args: GetEndpointGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEndpointGroupResult>;
export interface GetEndpointGroupOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the endpoint group
     */
    endpointGroupArn: pulumi.Input<string>;
}
