import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * AWS Ground Station config resource type for CloudFormation.
 */
export declare function getConfig(args: GetConfigArgs, opts?: pulumi.InvokeOptions): Promise<GetConfigResult>;
export interface GetConfigArgs {
    /**
     * The ARN of the config, such as `arn:aws:groundstation:us-east-2:1234567890:config/tracking/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    arn: string;
}
export interface GetConfigResult {
    /**
     * The ARN of the config, such as `arn:aws:groundstation:us-east-2:1234567890:config/tracking/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly arn?: string;
    /**
     * Object containing the parameters of a config. Only one subtype may be specified per config. See the subtype definitions for a description of each config subtype.
     */
    readonly configData?: outputs.groundstation.ConfigData;
    /**
     * The ID of the config, such as `9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly id?: string;
    /**
     * The name of the config object.
     */
    readonly name?: string;
    /**
     * Tags assigned to a resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The type of the config, such as `tracking` .
     */
    readonly type?: string;
}
/**
 * AWS Ground Station config resource type for CloudFormation.
 */
export declare function getConfigOutput(args: GetConfigOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfigResult>;
export interface GetConfigOutputArgs {
    /**
     * The ARN of the config, such as `arn:aws:groundstation:us-east-2:1234567890:config/tracking/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    arn: pulumi.Input<string>;
}
