import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates a fleet provisioning template.
 */
export declare function getProvisioningTemplate(args: GetProvisioningTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetProvisioningTemplateResult>;
export interface GetProvisioningTemplateArgs {
    /**
     * The name of the fleet provisioning template.
     */
    templateName: string;
}
export interface GetProvisioningTemplateResult {
    /**
     * The description of the fleet provisioning template.
     */
    readonly description?: string;
    /**
     * True to enable the fleet provisioning template, otherwise false.
     */
    readonly enabled?: boolean;
    /**
     * Creates a pre-provisioning hook template.
     */
    readonly preProvisioningHook?: outputs.iot.ProvisioningTemplateProvisioningHook;
    /**
     * The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.
     */
    readonly provisioningRoleArn?: string;
    /**
     * Metadata that can be used to manage the fleet provisioning template.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ARN that identifies the provisioning template.
     */
    readonly templateArn?: string;
    /**
     * The JSON formatted contents of the fleet provisioning template version.
     */
    readonly templateBody?: string;
}
/**
 * Creates a fleet provisioning template.
 */
export declare function getProvisioningTemplateOutput(args: GetProvisioningTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProvisioningTemplateResult>;
export interface GetProvisioningTemplateOutputArgs {
    /**
     * The name of the fleet provisioning template.
     */
    templateName: pulumi.Input<string>;
}
