import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A Kendra index
 */
export declare class Index extends pulumi.CustomResource {
    /**
     * Get an existing Index resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Index;
    /**
     * Returns true if the given object is an instance of Index.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Index;
    /**
     * The Amazon Resource Name (ARN) of the index. For example: `arn:aws:kendra:us-west-2:111122223333:index/0123456789abcdef` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The identifier for the index. For example: `f4aeaa10-8056-4b2c-a343-522ca0f41234` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Capacity units
     */
    readonly capacityUnits: pulumi.Output<outputs.kendra.IndexCapacityUnitsConfiguration | undefined>;
    /**
     * A description for the index
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Document metadata configurations
     */
    readonly documentMetadataConfigurations: pulumi.Output<outputs.kendra.IndexDocumentMetadataConfiguration[] | undefined>;
    /**
     * Indicates whether the index is a Enterprise Edition index, a Developer Edition index, or a GenAI Enterprise Edition index.
     */
    readonly edition: pulumi.Output<enums.kendra.IndexEdition>;
    /**
     * The name of the index.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An IAM role that gives Amazon Kendra permissions to access your Amazon CloudWatch logs and metrics. This is also the role used when you use the [BatchPutDocument](https://docs.aws.amazon.com/kendra/latest/dg/BatchPutDocument.html) operation to index documents from an Amazon S3 bucket.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * Server side encryption configuration
     */
    readonly serverSideEncryptionConfiguration: pulumi.Output<outputs.kendra.IndexServerSideEncryptionConfiguration | undefined>;
    /**
     * Tags for labeling the index
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The user context policy.
     *
     * ATTRIBUTE_FILTER
     *
     * - All indexed content is searchable and displayable for all users. If you want to filter search results on user context, you can use the attribute filters of `_user_id` and `_group_ids` or you can provide user and group information in `UserContext` .
     *
     * USER_TOKEN
     *
     * - Enables token-based user access control to filter search results on user context. All documents with no access control and all documents accessible to the user will be searchable and displayable.
     */
    readonly userContextPolicy: pulumi.Output<enums.kendra.IndexUserContextPolicy | undefined>;
    /**
     * Defines the type of user token used for the index.
     */
    readonly userTokenConfigurations: pulumi.Output<outputs.kendra.IndexUserTokenConfiguration[] | undefined>;
    /**
     * Create a Index resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IndexArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Index resource.
 */
export interface IndexArgs {
    /**
     * Capacity units
     */
    capacityUnits?: pulumi.Input<inputs.kendra.IndexCapacityUnitsConfigurationArgs>;
    /**
     * A description for the index
     */
    description?: pulumi.Input<string>;
    /**
     * Document metadata configurations
     */
    documentMetadataConfigurations?: pulumi.Input<pulumi.Input<inputs.kendra.IndexDocumentMetadataConfigurationArgs>[]>;
    /**
     * Indicates whether the index is a Enterprise Edition index, a Developer Edition index, or a GenAI Enterprise Edition index.
     */
    edition: pulumi.Input<enums.kendra.IndexEdition>;
    /**
     * The name of the index.
     */
    name?: pulumi.Input<string>;
    /**
     * An IAM role that gives Amazon Kendra permissions to access your Amazon CloudWatch logs and metrics. This is also the role used when you use the [BatchPutDocument](https://docs.aws.amazon.com/kendra/latest/dg/BatchPutDocument.html) operation to index documents from an Amazon S3 bucket.
     */
    roleArn: pulumi.Input<string>;
    /**
     * Server side encryption configuration
     */
    serverSideEncryptionConfiguration?: pulumi.Input<inputs.kendra.IndexServerSideEncryptionConfigurationArgs>;
    /**
     * Tags for labeling the index
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The user context policy.
     *
     * ATTRIBUTE_FILTER
     *
     * - All indexed content is searchable and displayable for all users. If you want to filter search results on user context, you can use the attribute filters of `_user_id` and `_group_ids` or you can provide user and group information in `UserContext` .
     *
     * USER_TOKEN
     *
     * - Enables token-based user access control to filter search results on user context. All documents with no access control and all documents accessible to the user will be searchable and displayable.
     */
    userContextPolicy?: pulumi.Input<enums.kendra.IndexUserContextPolicy>;
    /**
     * Defines the type of user token used for the index.
     */
    userTokenConfigurations?: pulumi.Input<pulumi.Input<inputs.kendra.IndexUserTokenConfigurationArgs>[]>;
}
