import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A resource schema representing a Lake Formation Tag Association. While tag associations are not explicit Lake Formation resources, this CloudFormation resource can be used to associate tags with Lake Formation entities.
 */
export declare class TagAssociation extends pulumi.CustomResource {
    /**
     * Get an existing TagAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TagAssociation;
    /**
     * Returns true if the given object is an instance of TagAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TagAssociation;
    /**
     * List of Lake Formation Tags to associate with the Lake Formation Resource
     */
    readonly lfTags: pulumi.Output<outputs.lakeformation.TagAssociationLfTagPair[]>;
    /**
     * Resource to tag with the Lake Formation Tags
     */
    readonly resource: pulumi.Output<outputs.lakeformation.TagAssociationResource>;
    /**
     * Unique string identifying the resource. Used as primary identifier, which ideally should be a string
     */
    readonly resourceIdentifier: pulumi.Output<string>;
    /**
     * Unique string identifying the resource's tags. Used as primary identifier, which ideally should be a string
     */
    readonly tagsIdentifier: pulumi.Output<string>;
    /**
     * Create a TagAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TagAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TagAssociation resource.
 */
export interface TagAssociationArgs {
    /**
     * List of Lake Formation Tags to associate with the Lake Formation Resource
     */
    lfTags: pulumi.Input<pulumi.Input<inputs.lakeformation.TagAssociationLfTagPairArgs>[]>;
    /**
     * Resource to tag with the Lake Formation Tags
     */
    resource: pulumi.Input<inputs.lakeformation.TagAssociationResourceArgs>;
}
