import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An Amazon Lookout for Metrics Detector
 */
export declare function getAnomalyDetector(args: GetAnomalyDetectorArgs, opts?: pulumi.InvokeOptions): Promise<GetAnomalyDetectorResult>;
export interface GetAnomalyDetectorArgs {
    /**
     * The Amazon Resource Name (ARN) of the detector. For example, `arn:aws:lookoutmetrics:us-east-2:123456789012:AnomalyDetector:my-detector`
     */
    arn: string;
}
export interface GetAnomalyDetectorResult {
    /**
     * Configuration options for the AnomalyDetector
     */
    readonly anomalyDetectorConfig?: outputs.lookoutmetrics.AnomalyDetectorConfig;
    /**
     * A description for the AnomalyDetector.
     */
    readonly anomalyDetectorDescription?: string;
    /**
     * The Amazon Resource Name (ARN) of the detector. For example, `arn:aws:lookoutmetrics:us-east-2:123456789012:AnomalyDetector:my-detector`
     */
    readonly arn?: string;
    /**
     * KMS key used to encrypt the AnomalyDetector data
     */
    readonly kmsKeyArn?: string;
    /**
     * List of metric sets for anomaly detection
     */
    readonly metricSetList?: outputs.lookoutmetrics.AnomalyDetectorMetricSet[];
}
/**
 * An Amazon Lookout for Metrics Detector
 */
export declare function getAnomalyDetectorOutput(args: GetAnomalyDetectorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAnomalyDetectorResult>;
export interface GetAnomalyDetectorOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the detector. For example, `arn:aws:lookoutmetrics:us-east-2:123456789012:AnomalyDetector:my-detector`
     */
    arn: pulumi.Input<string>;
}
