import * as pulumi from "@pulumi/pulumi";
/**
 * <p>Represents a resource policy that allows or denies access to an origin endpoint.</p>
 */
export declare class OriginEndpointPolicy extends pulumi.CustomResource {
    /**
     * Get an existing OriginEndpointPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OriginEndpointPolicy;
    /**
     * Returns true if the given object is an instance of OriginEndpointPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginEndpointPolicy;
    /**
     * The name of the channel group associated with the origin endpoint policy.
     */
    readonly channelGroupName: pulumi.Output<string>;
    /**
     * The channel name associated with the origin endpoint policy.
     */
    readonly channelName: pulumi.Output<string>;
    /**
     * The name of the origin endpoint associated with the origin endpoint policy.
     */
    readonly originEndpointName: pulumi.Output<string>;
    /**
     * The policy associated with the origin endpoint.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::MediaPackageV2::OriginEndpointPolicy` for more information about the expected schema for this property.
     */
    readonly policy: pulumi.Output<any>;
    /**
     * Create a OriginEndpointPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OriginEndpointPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OriginEndpointPolicy resource.
 */
export interface OriginEndpointPolicyArgs {
    /**
     * The name of the channel group associated with the origin endpoint policy.
     */
    channelGroupName: pulumi.Input<string>;
    /**
     * The channel name associated with the origin endpoint policy.
     */
    channelName: pulumi.Input<string>;
    /**
     * The name of the origin endpoint associated with the origin endpoint policy.
     */
    originEndpointName: pulumi.Input<string>;
    /**
     * The policy associated with the origin endpoint.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::MediaPackageV2::OriginEndpointPolicy` for more information about the expected schema for this property.
     */
    policy: any;
}
