import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::MediaTailor::VodSource Resource Type
 */
export declare class VodSource extends pulumi.CustomResource {
    /**
     * Get an existing VodSource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VodSource;
    /**
     * Returns true if the given object is an instance of VodSource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VodSource;
    /**
     * <p>The ARN of the VOD source.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * <p>A list of HTTP package configuration parameters for this VOD source.</p>
     */
    readonly httpPackageConfigurations: pulumi.Output<outputs.mediatailor.VodSourceHttpPackageConfiguration[]>;
    /**
     * The name of the source location that the VOD source is associated with.
     */
    readonly sourceLocationName: pulumi.Output<string>;
    /**
     * The tags to assign to the VOD source.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The name of the VOD source.
     */
    readonly vodSourceName: pulumi.Output<string>;
    /**
     * Create a VodSource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VodSourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VodSource resource.
 */
export interface VodSourceArgs {
    /**
     * <p>A list of HTTP package configuration parameters for this VOD source.</p>
     */
    httpPackageConfigurations: pulumi.Input<pulumi.Input<inputs.mediatailor.VodSourceHttpPackageConfigurationArgs>[]>;
    /**
     * The name of the source location that the VOD source is associated with.
     */
    sourceLocationName: pulumi.Input<string>;
    /**
     * The tags to assign to the VOD source.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the VOD source.
     */
    vodSourceName?: pulumi.Input<string>;
}
