import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a Connector that allows certificate issuance through Simple Certificate Enrollment Protocol (SCEP)
 */
export declare function getConnector(args: GetConnectorArgs, opts?: pulumi.InvokeOptions): Promise<GetConnectorResult>;
export interface GetConnectorArgs {
    /**
     * The Amazon Resource Name (ARN) of the connector.
     */
    connectorArn: string;
}
export interface GetConnectorResult {
    /**
     * The Amazon Resource Name (ARN) of the connector.
     */
    readonly connectorArn?: string;
    /**
     * The connector's HTTPS public SCEP URL.
     */
    readonly endpoint?: string;
    readonly openIdConfiguration?: outputs.pcaconnectorscep.ConnectorOpenIdConfiguration;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The connector type.
     */
    readonly type?: enums.pcaconnectorscep.ConnectorType;
}
/**
 * Represents a Connector that allows certificate issuance through Simple Certificate Enrollment Protocol (SCEP)
 */
export declare function getConnectorOutput(args: GetConnectorOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConnectorResult>;
export interface GetConnectorOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the connector.
     */
    connectorArn: pulumi.Input<string>;
}
