import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::Application Resource Type
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Q Business application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * The identifier for the Amazon Q Business application.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * Configuration information for the file upload during chat feature.
     */
    readonly attachmentsConfiguration: pulumi.Output<outputs.qbusiness.ApplicationAttachmentsConfiguration | undefined>;
    /**
     * Subscription configuration information for an Amazon Q Business application using IAM identity federation for user management.
     */
    readonly autoSubscriptionConfiguration: pulumi.Output<outputs.qbusiness.ApplicationAutoSubscriptionConfiguration | undefined>;
    /**
     * The OIDC client ID for a Amazon Q Business application.
     */
    readonly clientIdsForOidc: pulumi.Output<string[] | undefined>;
    /**
     * The Unix timestamp when the Amazon Q Business application was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A description for the Amazon Q Business application.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the Amazon Q Business application.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * Provides the identifier of the AWS KMS key used to encrypt data indexed by Amazon Q Business. Amazon Q Business doesn't support asymmetric keys.
     */
    readonly encryptionConfiguration: pulumi.Output<outputs.qbusiness.ApplicationEncryptionConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an identity provider being used by an Amazon Q Business application.
     */
    readonly iamIdentityProviderArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the AWS IAM Identity Center instance attached to your Amazon Q Business application.
     */
    readonly identityCenterApplicationArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM Identity Center instance you are either creating for—or connecting to—your Amazon Q Business application.
     *
     * *Required* : `Yes`
     */
    readonly identityCenterInstanceArn: pulumi.Output<string | undefined>;
    /**
     * The authentication type being used by a Amazon Q Business application.
     */
    readonly identityType: pulumi.Output<enums.qbusiness.ApplicationIdentityType | undefined>;
    /**
     * Configuration information about chat response personalization. For more information, see [Personalizing chat responses](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/personalizing-chat-responses.html) .
     */
    readonly personalizationConfiguration: pulumi.Output<outputs.qbusiness.ApplicationPersonalizationConfiguration | undefined>;
    /**
     * Configuration information about Amazon Q Apps.
     */
    readonly qAppsConfiguration: pulumi.Output<outputs.qbusiness.ApplicationQAppsConfiguration | undefined>;
    /**
     * The Amazon QuickSight configuration for an Amazon Q Business application that uses QuickSight as the identity provider.
     */
    readonly quickSightConfiguration: pulumi.Output<outputs.qbusiness.ApplicationQuickSightConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role with permissions to access your Amazon CloudWatch logs and metrics. If this property is not specified, Amazon Q Business will create a [service linked role (SLR)](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/using-service-linked-roles.html#slr-permissions) and use it as the application's role.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The status of the Amazon Q Business application. The application is ready to use when the status is `ACTIVE` .
     */
    readonly status: pulumi.Output<enums.qbusiness.ApplicationStatus>;
    /**
     * A list of key-value pairs that identify or categorize your Amazon Q Business application. You can also use tags to help control access to the application. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The Unix timestamp when the Amazon Q Business application was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * Configuration information for the file upload during chat feature.
     */
    attachmentsConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationAttachmentsConfigurationArgs>;
    /**
     * Subscription configuration information for an Amazon Q Business application using IAM identity federation for user management.
     */
    autoSubscriptionConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationAutoSubscriptionConfigurationArgs>;
    /**
     * The OIDC client ID for a Amazon Q Business application.
     */
    clientIdsForOidc?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A description for the Amazon Q Business application.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the Amazon Q Business application.
     */
    displayName: pulumi.Input<string>;
    /**
     * Provides the identifier of the AWS KMS key used to encrypt data indexed by Amazon Q Business. Amazon Q Business doesn't support asymmetric keys.
     */
    encryptionConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationEncryptionConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) of an identity provider being used by an Amazon Q Business application.
     */
    iamIdentityProviderArn?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM Identity Center instance you are either creating for—or connecting to—your Amazon Q Business application.
     *
     * *Required* : `Yes`
     */
    identityCenterInstanceArn?: pulumi.Input<string>;
    /**
     * The authentication type being used by a Amazon Q Business application.
     */
    identityType?: pulumi.Input<enums.qbusiness.ApplicationIdentityType>;
    /**
     * Configuration information about chat response personalization. For more information, see [Personalizing chat responses](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/personalizing-chat-responses.html) .
     */
    personalizationConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationPersonalizationConfigurationArgs>;
    /**
     * Configuration information about Amazon Q Apps.
     */
    qAppsConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationQAppsConfigurationArgs>;
    /**
     * The Amazon QuickSight configuration for an Amazon Q Business application that uses QuickSight as the identity provider.
     */
    quickSightConfiguration?: pulumi.Input<inputs.qbusiness.ApplicationQuickSightConfigurationArgs>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role with permissions to access your Amazon CloudWatch logs and metrics. If this property is not specified, Amazon Q Business will create a [service linked role (SLR)](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/using-service-linked-roles.html#slr-permissions) and use it as the application's role.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that identify or categorize your Amazon Q Business application. You can also use tags to help control access to the application. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
