import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of the AWS::QuickSight::Analysis Resource Type.
 */
export declare class Analysis extends pulumi.CustomResource {
    /**
     * Get an existing Analysis resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Analysis;
    /**
     * Returns true if the given object is an instance of Analysis.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Analysis;
    /**
     * The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
     */
    readonly analysisId: pulumi.Output<string>;
    /**
     * <p>The Amazon Resource Name (ARN) of the analysis.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the AWS account where you are creating an analysis.
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * <p>The time that the analysis was created.</p>
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * <p>The ARNs of the datasets of the analysis.</p>
     */
    readonly dataSetArns: pulumi.Output<string[]>;
    readonly definition: pulumi.Output<outputs.quicksight.AnalysisDefinition | undefined>;
    /**
     * <p>Errors associated with the analysis.</p>
     */
    readonly errors: pulumi.Output<outputs.quicksight.AnalysisError[] | undefined>;
    readonly folderArns: pulumi.Output<string[] | undefined>;
    /**
     * <p>The time that the analysis was last updated.</p>
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * <p>The descriptive name of the analysis.</p>
     */
    readonly name: pulumi.Output<string>;
    /**
     * The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
     */
    readonly parameters: pulumi.Output<outputs.quicksight.AnalysisParameters | undefined>;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis. You can use the `Permissions` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).
     *
     * To specify no permissions, omit `Permissions` .
     */
    readonly permissions: pulumi.Output<outputs.quicksight.AnalysisResourcePermission[] | undefined>;
    /**
     * <p>A list of the associated sheets with the unique identifier and name of each sheet.</p>
     */
    readonly sheets: pulumi.Output<outputs.quicksight.AnalysisSheet[] | undefined>;
    /**
     * A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     */
    readonly sourceEntity: pulumi.Output<outputs.quicksight.AnalysisSourceEntity | undefined>;
    /**
     * Status associated with the analysis.
     */
    readonly status: pulumi.Output<enums.quicksight.AnalysisResourceStatus | undefined>;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * <p>The ARN of the theme of the analysis.</p>
     */
    readonly themeArn: pulumi.Output<string | undefined>;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to `LENIENT` , validation is skipped for specific errors.
     */
    readonly validationStrategy: pulumi.Output<outputs.quicksight.AnalysisValidationStrategy | undefined>;
    /**
     * Create a Analysis resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AnalysisArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Analysis resource.
 */
export interface AnalysisArgs {
    /**
     * The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
     */
    analysisId: pulumi.Input<string>;
    /**
     * The ID of the AWS account where you are creating an analysis.
     */
    awsAccountId: pulumi.Input<string>;
    definition?: pulumi.Input<inputs.quicksight.AnalysisDefinitionArgs>;
    /**
     * <p>Errors associated with the analysis.</p>
     */
    errors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisErrorArgs>[]>;
    folderArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * <p>The descriptive name of the analysis.</p>
     */
    name?: pulumi.Input<string>;
    /**
     * The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
     */
    parameters?: pulumi.Input<inputs.quicksight.AnalysisParametersArgs>;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis. You can use the `Permissions` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).
     *
     * To specify no permissions, omit `Permissions` .
     */
    permissions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisResourcePermissionArgs>[]>;
    /**
     * <p>A list of the associated sheets with the unique identifier and name of each sheet.</p>
     */
    sheets?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetArgs>[]>;
    /**
     * A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     */
    sourceEntity?: pulumi.Input<inputs.quicksight.AnalysisSourceEntityArgs>;
    /**
     * Status associated with the analysis.
     */
    status?: pulumi.Input<enums.quicksight.AnalysisResourceStatus>;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * <p>The ARN of the theme of the analysis.</p>
     */
    themeArn?: pulumi.Input<string>;
    /**
     * The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to `LENIENT` , validation is skipped for specific errors.
     */
    validationStrategy?: pulumi.Input<inputs.quicksight.AnalysisValidationStrategyArgs>;
}
