import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::RDS::DBProxyEndpoint.
 */
export declare function getDbProxyEndpoint(args: GetDbProxyEndpointArgs, opts?: pulumi.InvokeOptions): Promise<GetDbProxyEndpointResult>;
export interface GetDbProxyEndpointArgs {
    /**
     * The identifier for the DB proxy endpoint. This name must be unique for all DB proxy endpoints owned by your AWS account in the specified AWS Region.
     */
    dbProxyEndpointName: string;
}
export interface GetDbProxyEndpointResult {
    /**
     * The Amazon Resource Name (ARN) for the DB proxy endpoint.
     */
    readonly dbProxyEndpointArn?: string;
    /**
     * The endpoint that you can use to connect to the DB proxy. You include the endpoint value in the connection string for a database client application.
     */
    readonly endpoint?: string;
    /**
     * A value that indicates whether this endpoint is the default endpoint for the associated DB proxy. Default DB proxy endpoints always have read/write capability. Other endpoints that you associate with the DB proxy can be either read/write or read-only.
     */
    readonly isDefault?: boolean;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB proxy endpoint.
     */
    readonly tags?: outputs.Tag[];
    /**
     * A value that indicates whether the DB proxy endpoint can be used for read/write or read-only operations.
     */
    readonly targetRole?: enums.rds.DbProxyEndpointTargetRole;
    /**
     * VPC ID to associate with the new DB proxy endpoint.
     */
    readonly vpcId?: string;
    /**
     * VPC security group IDs to associate with the new DB proxy endpoint.
     */
    readonly vpcSecurityGroupIds?: string[];
}
/**
 * Resource schema for AWS::RDS::DBProxyEndpoint.
 */
export declare function getDbProxyEndpointOutput(args: GetDbProxyEndpointOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDbProxyEndpointResult>;
export interface GetDbProxyEndpointOutputArgs {
    /**
     * The identifier for the DB proxy endpoint. This name must be unique for all DB proxy endpoints owned by your AWS account in the specified AWS Region.
     */
    dbProxyEndpointName: pulumi.Input<string>;
}
