import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::RolesAnywhere::Profile Resource Type
 */
export declare function getProfile(args: GetProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetProfileResult>;
export interface GetProfileArgs {
    /**
     * The unique primary identifier of the Profile
     */
    profileId: string;
}
export interface GetProfileResult {
    /**
     * Used to determine if a custom role session name will be accepted in a temporary credential request.
     */
    readonly acceptRoleSessionName?: boolean;
    /**
     * A mapping applied to the authenticating end-entity certificate.
     */
    readonly attributeMappings?: outputs.rolesanywhere.ProfileAttributeMapping[];
    /**
     * The number of seconds vended session credentials will be valid for
     */
    readonly durationSeconds?: number;
    /**
     * The enabled status of the resource.
     */
    readonly enabled?: boolean;
    /**
     * A list of managed policy ARNs. Managed policies identified by this list will be applied to the vended session credentials.
     */
    readonly managedPolicyArns?: string[];
    /**
     * The customer specified name of the resource.
     */
    readonly name?: string;
    /**
     * The ARN of the profile.
     */
    readonly profileArn?: string;
    /**
     * The unique primary identifier of the Profile
     */
    readonly profileId?: string;
    /**
     * A list of IAM role ARNs that can be assumed when this profile is specified in a CreateSession request.
     */
    readonly roleArns?: string[];
    /**
     * A session policy that will applied to the trust boundary of the vended session credentials.
     */
    readonly sessionPolicy?: string;
    /**
     * A list of Tags.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::RolesAnywhere::Profile Resource Type
 */
export declare function getProfileOutput(args: GetProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProfileResult>;
export interface GetProfileOutputArgs {
    /**
     * The unique primary identifier of the Profile
     */
    profileId: pulumi.Input<string>;
}
