import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates an Amazon S3 Tables table bucket in the same AWS Region where you create the AWS CloudFormation stack.
 */
export declare function getTableBucket(args: GetTableBucketArgs, opts?: pulumi.InvokeOptions): Promise<GetTableBucketResult>;
export interface GetTableBucketArgs {
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    tableBucketArn: string;
}
export interface GetTableBucketResult {
    /**
     * Configuration specifying how data should be encrypted. This structure defines the encryption algorithm and optional KMS key to be used for server-side encryption.
     */
    readonly encryptionConfiguration?: outputs.s3tables.TableBucketEncryptionConfiguration;
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    readonly tableBucketArn?: string;
    /**
     * The unreferenced file removal settings for your table bucket. Unreferenced file removal identifies and deletes all objects that are not referenced by any table snapshots. For more information, see the [*Amazon S3 User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-table-buckets-maintenance.html) .
     */
    readonly unreferencedFileRemoval?: outputs.s3tables.TableBucketUnreferencedFileRemoval;
}
/**
 * Creates an Amazon S3 Tables table bucket in the same AWS Region where you create the AWS CloudFormation stack.
 */
export declare function getTableBucketOutput(args: GetTableBucketOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTableBucketResult>;
export interface GetTableBucketOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    tableBucketArn: pulumi.Input<string>;
}
