import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::App
 */
export declare class App extends pulumi.CustomResource {
    /**
     * Get an existing App resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): App;
    /**
     * Returns true if the given object is an instance of App.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is App;
    /**
     * The Amazon Resource Name (ARN) of the app.
     */
    readonly appArn: pulumi.Output<string>;
    /**
     * The name of the app.
     */
    readonly appName: pulumi.Output<string>;
    /**
     * The type of app.
     */
    readonly appType: pulumi.Output<enums.sagemaker.AppType>;
    /**
     * The lifecycle configuration that runs before the default lifecycle configuration.
     */
    readonly builtInLifecycleConfigArn: pulumi.Output<string>;
    /**
     * The domain ID.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * Indicates whether the application is launched in recovery mode.
     */
    readonly recoveryMode: pulumi.Output<boolean | undefined>;
    /**
     * The instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance.
     */
    readonly resourceSpec: pulumi.Output<outputs.sagemaker.AppResourceSpec | undefined>;
    /**
     * A list of tags to apply to the app.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * The user profile name.
     */
    readonly userProfileName: pulumi.Output<string>;
    /**
     * Create a App resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a App resource.
 */
export interface AppArgs {
    /**
     * The name of the app.
     */
    appName?: pulumi.Input<string>;
    /**
     * The type of app.
     */
    appType: pulumi.Input<enums.sagemaker.AppType>;
    /**
     * The domain ID.
     */
    domainId: pulumi.Input<string>;
    /**
     * Indicates whether the application is launched in recovery mode.
     */
    recoveryMode?: pulumi.Input<boolean>;
    /**
     * The instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance.
     */
    resourceSpec?: pulumi.Input<inputs.sagemaker.AppResourceSpecArgs>;
    /**
     * A list of tags to apply to the app.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
    /**
     * The user profile name.
     */
    userProfileName: pulumi.Input<string>;
}
