import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A signing profile is a signing template that can be used to carry out a pre-defined signing job.
 */
export declare function getSigningProfile(args: GetSigningProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetSigningProfileResult>;
export interface GetSigningProfileArgs {
    /**
     * The Amazon Resource Name (ARN) of the specified signing profile.
     */
    arn: string;
}
export interface GetSigningProfileResult {
    /**
     * The Amazon Resource Name (ARN) of the specified signing profile.
     */
    readonly arn?: string;
    /**
     * A version for the signing profile. AWS Signer generates a unique version for each profile of the same profile name.
     */
    readonly profileVersion?: string;
    /**
     * The Amazon Resource Name (ARN) of the specified signing profile version.
     */
    readonly profileVersionArn?: string;
    /**
     * A list of tags associated with the signing profile.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A signing profile is a signing template that can be used to carry out a pre-defined signing job.
 */
export declare function getSigningProfileOutput(args: GetSigningProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSigningProfileResult>;
export interface GetSigningProfileOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the specified signing profile.
     */
    arn: pulumi.Input<string>;
}
