import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Synthetics::Canary
 */
export declare function getCanary(args: GetCanaryArgs, opts?: pulumi.InvokeOptions): Promise<GetCanaryResult>;
export interface GetCanaryArgs {
    /**
     * Name of the canary.
     */
    name: string;
}
export interface GetCanaryResult {
    /**
     * Provide artifact configuration
     */
    readonly artifactConfig?: outputs.synthetics.CanaryArtifactConfig;
    /**
     * Provide the s3 bucket output location for test results
     */
    readonly artifactS3Location?: string;
    /**
     * Provide the canary script source
     */
    readonly code?: outputs.synthetics.CanaryCode;
    /**
     * Lambda Execution role used to run your canaries
     */
    readonly executionRoleArn?: string;
    /**
     * Retention period of failed canary runs represented in number of days
     */
    readonly failureRetentionPeriod?: number;
    /**
     * Id of the canary
     */
    readonly id?: string;
    /**
     * Setting to control if provisioned resources created by Synthetics are deleted alongside the canary. Default is AUTOMATIC.
     */
    readonly provisionedResourceCleanup?: enums.synthetics.CanaryProvisionedResourceCleanup;
    /**
     * Provide canary run configuration
     */
    readonly runConfig?: outputs.synthetics.CanaryRunConfig;
    /**
     * Runtime version of Synthetics Library
     */
    readonly runtimeVersion?: string;
    /**
     * Frequency to run your canaries
     */
    readonly schedule?: outputs.synthetics.CanarySchedule;
    /**
     * State of the canary
     */
    readonly state?: string;
    /**
     * Retention period of successful canary runs represented in number of days
     */
    readonly successRetentionPeriod?: number;
    /**
     * The list of key-value pairs that are associated with the canary.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Provide VPC Configuration if enabled.
     */
    readonly vpcConfig?: outputs.synthetics.CanaryVpcConfig;
}
/**
 * Resource Type definition for AWS::Synthetics::Canary
 */
export declare function getCanaryOutput(args: GetCanaryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCanaryResult>;
export interface GetCanaryOutputArgs {
    /**
     * Name of the canary.
     */
    name: pulumi.Input<string>;
}
