import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Synthetics::Group
 */
export declare class Group extends pulumi.CustomResource {
    /**
     * Get an existing Group resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Group;
    /**
     * Returns true if the given object is an instance of Group.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Group;
    /**
     * Id of the group.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Name of the group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARNs of the canaries that you want to associate with this group.
     */
    readonly resourceArns: pulumi.Output<string[] | undefined>;
    /**
     * The list of key-value pairs that are associated with the group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Group resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: GroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Group resource.
 */
export interface GroupArgs {
    /**
     * Name of the group.
     */
    name?: pulumi.Input<string>;
    /**
     * The ARNs of the canaries that you want to associate with this group.
     */
    resourceArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of key-value pairs that are associated with the group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
