import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * This schema provides construct and validation rules for AWS-XRay Group resource parameters.
 */
export declare function getGroup(args: GetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetGroupResult>;
export interface GetGroupArgs {
    /**
     * The ARN of the group that was generated on creation.
     */
    groupArn: string;
}
export interface GetGroupResult {
    /**
     * The filter expression defining criteria by which to group traces.
     */
    readonly filterExpression?: string;
    /**
     * The ARN of the group that was generated on creation.
     */
    readonly groupArn?: string;
    /**
     * The case-sensitive name of the new group. Names must be unique.
     */
    readonly groupName?: string;
    /**
     * The structure containing configurations related to insights.
     *
     * - The InsightsEnabled boolean can be set to true to enable insights for the group or false to disable insights for the group.
     * - The NotificationsEnabled boolean can be set to true to enable insights notifications through Amazon EventBridge for the group.
     */
    readonly insightsConfiguration?: outputs.xray.GroupInsightsConfiguration;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * This schema provides construct and validation rules for AWS-XRay Group resource parameters.
 */
export declare function getGroupOutput(args: GetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGroupResult>;
export interface GetGroupOutputArgs {
    /**
     * The ARN of the group that was generated on creation.
     */
    groupArn: pulumi.Input<string>;
}
